git-whence-0.2.0 is not a library.
git-whence is an interactive version of git-blame that makes it easy to reblame at a previous version and follow a line through commit history
git whence src/git.rs
<Enter> to follow a line through commit history
<Esc> or q, then b to reblame at a previous version
B will pop the stack and blame at the initial version (first screenshot)